@@ -263,13 +263,13 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk
-import aws_cdk.aws_iam
-import constructs
+import aws_cdk as _aws_cdk_ceddda9d
+import aws_cdk.aws_iam as _aws_cdk_aws_iam_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class RemoteOutputs(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-remote-stack.RemoteOutputs",
 ):
@@ -277,10 +277,10 @@ class RemoteOutputs(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
-        stack: aws_cdk.Stack,
+        stack: _aws_cdk_ceddda9d.Stack,
         always_update: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''
@@ -290,7 +290,7 @@ class RemoteOutputs(
         :param always_update: Indicate whether always update the custom resource to get the new stack output. Default: true
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RemoteOutputs.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__f24236c27040f7b9cc5ff175c0c31066ded2ac502db53b338268c0df35d96ad9)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = RemoteOutputsProps(stack=stack, always_update=always_update)
@@ -304,15 +304,15 @@ class RemoteOutputs(
         :param key: output key.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RemoteOutputs.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__b47bc8a37ed4186ba6632caacdff833e61cf684d4699c5386092fc102735293d)
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         return typing.cast(builtins.str, jsii.invoke(self, "get", [key]))
 
     @builtins.property
     @jsii.member(jsii_name="outputs")
-    def outputs(self) -> aws_cdk.CustomResource:
+    def outputs(self) -> _aws_cdk_ceddda9d.CustomResource:
         '''The outputs from the remote stack.'''
-        return typing.cast(aws_cdk.CustomResource, jsii.get(self, "outputs"))
+        return typing.cast(_aws_cdk_ceddda9d.CustomResource, jsii.get(self, "outputs"))
 
 
 @jsii.data_type(
@@ -324,7 +324,7 @@ class RemoteOutputsProps:
     def __init__(
         self,
         *,
-        stack: aws_cdk.Stack,
+        stack: _aws_cdk_ceddda9d.Stack,
         always_update: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Properties of the RemoteOutputs.
@@ -333,21 +333,21 @@ class RemoteOutputsProps:
         :param always_update: Indicate whether always update the custom resource to get the new stack output. Default: true
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RemoteOutputsProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__368d5fc102ef388919139b6aaa3087e1b3d7b9e376b8d53ba7009b36628f38b0)
             check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
             check_type(argname="argument always_update", value=always_update, expected_type=type_hints["always_update"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "stack": stack,
         }
         if always_update is not None:
             self._values["always_update"] = always_update
 
     @builtins.property
-    def stack(self) -> aws_cdk.Stack:
+    def stack(self) -> _aws_cdk_ceddda9d.Stack:
         '''The remote CDK stack to get the outputs from.'''
         result = self._values.get("stack")
         assert result is not None, "Required property 'stack' is missing"
-        return typing.cast(aws_cdk.Stack, result)
+        return typing.cast(_aws_cdk_ceddda9d.Stack, result)
 
     @builtins.property
     def always_update(self) -> typing.Optional[builtins.bool]:
@@ -371,7 +371,7 @@ class RemoteOutputsProps:
 
 
 class RemoteParameters(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-remote-stack.RemoteParameters",
 ):
@@ -379,13 +379,13 @@ class RemoteParameters(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         path: builtins.str,
         region: builtins.str,
         always_update: typing.Optional[builtins.bool] = None,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
     ) -> None:
         '''
         :param scope: -
@@ -396,7 +396,7 @@ class RemoteParameters(
         :param role: The assumed role used to get remote parameters.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RemoteParameters.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__488dee44498e6139f96ea9010f7986ea24b72f85e053f11d09de524b6724a971)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = RemoteParametersProps(
@@ -412,15 +412,15 @@ class RemoteParameters(
         :param key: output key.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RemoteParameters.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__9fce64c126c7a91bf39bb51247494cab3c176b8470a6a5f51d8990a337f3efea)
             check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         return typing.cast(builtins.str, jsii.invoke(self, "get", [key]))
 
     @builtins.property
     @jsii.member(jsii_name="parameters")
-    def parameters(self) -> aws_cdk.CustomResource:
+    def parameters(self) -> _aws_cdk_ceddda9d.CustomResource:
         '''The parameters in the SSM parameter store for the remote stack.'''
-        return typing.cast(aws_cdk.CustomResource, jsii.get(self, "parameters"))
+        return typing.cast(_aws_cdk_ceddda9d.CustomResource, jsii.get(self, "parameters"))
 
 
 @jsii.data_type(
@@ -440,7 +440,7 @@ class RemoteParametersProps:
         path: builtins.str,
         region: builtins.str,
         always_update: typing.Optional[builtins.bool] = None,
-        role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
+        role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
     ) -> None:
         '''Properties of the RemoteParameters.
 
@@ -450,12 +450,12 @@ class RemoteParametersProps:
         :param role: The assumed role used to get remote parameters.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RemoteParametersProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__04433dd9b06dd5bc27731917ed54d12e38b4da10c79010d6082a912a5839bdf7)
             check_type(argname="argument path", value=path, expected_type=type_hints["path"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument always_update", value=always_update, expected_type=type_hints["always_update"])
             check_type(argname="argument role", value=role, expected_type=type_hints["role"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "path": path,
             "region": region,
         }
@@ -488,10 +488,10 @@ class RemoteParametersProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def role(self) -> typing.Optional[aws_cdk.aws_iam.IRole]:
+    def role(self) -> typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole]:
         '''The assumed role used to get remote parameters.'''
         result = self._values.get("role")
-        return typing.cast(typing.Optional[aws_cdk.aws_iam.IRole], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -513,3 +513,55 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__f24236c27040f7b9cc5ff175c0c31066ded2ac502db53b338268c0df35d96ad9(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    stack: _aws_cdk_ceddda9d.Stack,
+    always_update: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b47bc8a37ed4186ba6632caacdff833e61cf684d4699c5386092fc102735293d(
+    key: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__368d5fc102ef388919139b6aaa3087e1b3d7b9e376b8d53ba7009b36628f38b0(
+    *,
+    stack: _aws_cdk_ceddda9d.Stack,
+    always_update: typing.Optional[builtins.bool] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__488dee44498e6139f96ea9010f7986ea24b72f85e053f11d09de524b6724a971(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    path: builtins.str,
+    region: builtins.str,
+    always_update: typing.Optional[builtins.bool] = None,
+    role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__9fce64c126c7a91bf39bb51247494cab3c176b8470a6a5f51d8990a337f3efea(
+    key: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__04433dd9b06dd5bc27731917ed54d12e38b4da10c79010d6082a912a5839bdf7(
+    *,
+    path: builtins.str,
+    region: builtins.str,
+    always_update: typing.Optional[builtins.bool] = None,
+    role: typing.Optional[_aws_cdk_aws_iam_ceddda9d.IRole] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
